@@ -7,7 +7,7 @@ import gtk
 import atheist
 from atheist.const import *
 from atheist.manager import Manager
-from atheist.utils import compath
+from atheist.utils import relpath
 import pyarco.UI
 
 pyarco.UI.get_ostream().color = False
@@ -49,7 +49,7 @@ class AtheistGui:
 
             iter_ = self.store.append(None)
             self.store.set(iter_,
-                           1, compath(case.fname),
+                           1, relpath(case.fname),
                            2, "Case",
                            4, result,
                            5, bgcolor,
