@@ -1,14 +1,18 @@
 # -*- mode: python; coding: utf-8 -*-
 
-import os, re
+import pwd, os, re
 
-VERSION = '0.20101024'
+VERSION = '0.20110402'
 
 SETUP    = '_setup.test'
 TEARDOWN = '_teardown.test'
+DIR_SETUP = '_SETUP.test'
+DIR_TEARDOWN = '_TEARDOWN.test'
+
+SPECIAL = [SETUP, TEARDOWN, DIR_SETUP, DIR_TEARDOWN]
 
 # FIXME: fichero de configuración .atheist
-EXCLUDE = ['.svn', '.hg', SETUP, TEARDOWN]
+EXCLUDE = ['.svn', '.hg'] + SPECIAL
 
 INCLUDE_RE = re.compile(r"""include\("([\./\w\d]+)"\)\s*$""")
 
@@ -20,7 +24,8 @@ NOEXEC =  2       # Never executed
 ERROR =   3       # The task itself produced an unexpected error
 UNKNOWN = 4
 TODO    = 5
-mild_FAIL = 6
+SOFT_FAIL = 6
+MISCONF = 7
 
 STR_STATUS = {\
     FAIL:      'FAIL',
@@ -29,11 +34,13 @@ STR_STATUS = {\
     ERROR:     ' !! ',
     UNKNOWN:   ' ?? ',
     TODO:      'ToDo',
-    mild_FAIL: 'fail'
+    SOFT_FAIL: 'fail',
+    MISCONF:   'conf',
     }
 
 ATHEIST_BASE = os.path.join(os.environ['HOME'], '.atheist')
-ATHEIST_TMP =  '/tmp/atheist'
+ATHEIST_TMP_BASE = os.path.join('/tmp', 'atheist-{0}'.format(pwd.getpwuid(os.getuid())[0]))
+ATHEIST_TMP =  os.path.join(ATHEIST_TMP_BASE, str(os.getpid()))
 ATHEIST_CFG =  os.path.join(ATHEIST_BASE, 'config')
 ATHEIST_LOG =  os.path.join(ATHEIST_BASE, 'log')
 ATHEIST_EXT = '.test'
@@ -41,6 +48,6 @@ ATHEIST_EXT = '.test'
 USAGE = '''atheist [options] [file|directory]
 
 atheist is a testing tool.
-This is version %s, Copyright (C) 2009,2010 David Villa Alises
+This is version %s, Copyright (C) 2009,2010,2011 David Villa Alises
 atheist comes with ABSOLUTELY NO WARRANTY; This is free software, and you are
 welcome to redistribute it under certain conditions; See COPYING for details.''' % VERSION
