@@ -14,7 +14,15 @@ class CompositeCondition(atheist.ConditionDecorator, atheist.Plugin):
         atheist.ConditionDecorator.__init__(self, *conds)
 
     def run(self):
-        return self.oper([c.run() for c in self.conds])
+        return self.oper([c.run() for c in self.children])
+
+    @property
+    def name(self):
+        return self.__class__.__name__
+
+    def basic_info(self):
+        return str.join(', ', ["{0}({1})".format(x.name, x.basic_info())
+                                                for x in self.children])
 
 class Or(CompositeCondition, atheist.Plugin):
     def __init__(self, *conds):
