@@ -6,17 +6,18 @@ import atheist
 
 class DocTest(atheist.Plugin, atheist.Task):
     acro = 'DocT'
-    allows = ['cwd', 'delay', 'desc', 'must_fail', 'template', 'tid']
+    allows = ['cwd', 'must_fail']
+    concurrent = False
 
-    def __init__(self, module_name, **kargs):
+    def __init__(self, mng, module_name, **kargs):
         self.module_name = module_name
         self.check = True
 
-        atheist.Task.__init__(self, **kargs)
+        atheist.Task.__init__(self, mng, **kargs)
         self.wrap_outs = True
 
 
-    def exec_task(self):
+    def run(self):
         self.log.debug("runing doctest")
 
         if self.cwd:
@@ -25,12 +26,13 @@ class DocTest(atheist.Plugin, atheist.Task):
         try:
             module = __import__(self.module_name, fromlist=self.module_name.split('.')[-1])
             self.log.debug("%s" % module)
-            self.result = (doctest.testmod(module)[0] == 0)
+            retval = (doctest.testmod(module)[0] == 0)
             del module
+            return retval
 
         except ImportError, e:
             atheist.Log.warning(e)
-            self.result = atheist.ERROR
+            return atheist.ERROR
 
 
     def str_param(self):
