@@ -1,10 +1,10 @@
-
 import os
+import socket
 
 import atheist
 from atheist.gvar import Log
 
-class OpenPort(atheist.Condition):
+class OpenPort(atheist.Condition, atheist.Plugin):
     def __init__(self, port, host='localhost', proto='tcp'):
         assert proto in ['tcp','udp']
         assert isinstance(port , int) and 0 < port < 65535
@@ -23,6 +23,12 @@ class OpenPort(atheist.Condition):
 
         return self.remoteport()
 
+    def __eq__(self, other):
+        return atheist.Condition.__eq__(self, other) and \
+            self.port == other.port and \
+            self.host == other.host and \
+            self.proto == other.proto
+
     def localport(self):
         return os.system('fuser -n %s %s > /dev/null 2> /dev/null' % \
                              (self.proto, self.port)) == 0
@@ -35,7 +41,7 @@ class OpenPort(atheist.Condition):
         s.settimeout(1)
         try:
             s.connect((self.host, self.port))
-            s.shudown()
+            s.shutdown(socket.SHUT_RDWR)
             s.close()
             return True
         except socket.error, e:
@@ -44,4 +50,3 @@ class OpenPort(atheist.Condition):
 
     def basic_info(self):
         return "'%s %s/%s'" % (self.host, self.proto, self.port)
-
