@@ -14,14 +14,13 @@ class TimeLessThan(atheist.Condition, atheist.Plugin):
         self.tini = None
         self.tend = None
 
-    def before(self, task, condlist, pos):
+    def pre_task_run(self, task, condlist):
         self.tini = time.time()
-        atheist.Condition.before(self, task, condlist, pos)
-
-    def after(self):
-        self.tend = time.time()
+        return atheist.Condition.pre_task_run(self, task, condlist)
 
     def run(self):
+        self.tend = time.time()
+
         assert self.tini is not None, "Internal error"
         assert self.tend is not None, "Internal error"
 
