@@ -51,20 +51,20 @@ class client(Ice.Application):
         base = ic.stringToProxy(ic.getProperties().getProperty("Manager.Proxy"))
         print base
 
-        self.mgr = Atheist.ManagerPrx.checkedCast(base)
+        self.mng = Atheist.ManagerPrx.checkedCast(base)
 
-        if not self.mgr:
+        if not self.mng:
             raise RuntimeError("Invalid proxy")
 
-        self.mgr.attachStatusOb(
+        self.mng.attachStatusOb(
             Atheist.StatusObserverPrx.uncheckedCast(
                 adapter.addWithUUID(StatusObserverI())))
 
-        self.mgr.attachOutOb(
+        self.mng.attachOutOb(
             Atheist.OutObserverPrx.uncheckedCast(
                 adapter.addWithUUID(OutObserverI())).ice_batchOneway(), [])
 
-        self.mgr.attachLogOb(
+        self.mng.attachLogOb(
             Atheist.LogObserverPrx.uncheckedCast(
                 adapter.addWithUUID(LogObserverI())).ice_batchOneway(), [])
 
@@ -85,12 +85,12 @@ class client(Ice.Application):
     def event(self):
         print 'Event!'
 
-        cases = self.mgr.getTaskCases()
+        cases = self.mng.getTaskCases()
         if cases:
             print len(cases), "task cases"
             print cases[0].getConfig()
 
-        self.mgr.ice_oneway().runAll()
+        self.mng.ice_oneway().runAll()
         print "FIN ------------"
         gobject.timeout_add(20000, self.event)
 
