@@ -28,24 +28,24 @@ def get_proxies(adapter, cast, servants):
 
 class TaskCaseI(rath.TaskCase):
 
-    def __init__(self, mgr, tc):
-        self.mgr = mgr
+    def __init__(self, mng, tc):
+        self.mng = mng
         self.tc = tc
         self.lock = threading.Lock()
 
     # from TaskCase interface
     def run(self, current=None):
-        self.mgr.statusOb.updateTaskCases({self.tc.fname: rath.Status.RUNNING})
+        self.mng.statusOb.updateTaskCases({self.tc.fname: rath.Status.RUNNING})
 
         if self.lock.locked(): return
 
         with self.lock:
             self.tc.run()
-            self.mgr.statusOb.updateTasks(
+            self.mng.statusOb.updateTasks(
                 dict([("%s:%s" % (t.fname, t.name),
                        rath.Status(t.result)) for t in self.tc.tasks]))
 
-            self.mgr.statusOb.updateTaskCases(
+            self.mng.statusOb.updateTaskCases(
                 {self.tc.fname: rath.Status(self.tc.result)})
 
 
@@ -69,7 +69,7 @@ class TaskCaseI(rath.TaskCase):
 class ManagerI(rath.Manager):
 
     def __init__(self, argv, adap):
-        self.mgr = Manager(argv)
+        self.mng = Manager(argv)
         self.adap = adap
         self.statusOb = None
         self.outOb = None
@@ -85,12 +85,12 @@ class ManagerI(rath.Manager):
         for prx in self.proxies:
             self.adap.remove(prx.ice_getIdentity())
 
-        self.mgr.reload()
-        self.cases = [TaskCaseI(self,x) for x in self.mgr.itercases()]
+        self.mng.reload()
+        self.cases = [TaskCaseI(self,x) for x in self.mng.itercases()]
         self.proxies = get_proxies(self.adap, rath.TaskCasePrx,
                                    self.cases)
 
-        for c in self.mgr.itercases():
+        for c in self.mng.itercases():
             print c
 
         log.info("cases: %s" % len(self.cases))
