@@ -34,7 +34,7 @@ signal.signal(signal.SIGINT, abort_handler)
 while 1:
     time.sleep(1)
     if abort:
-        print 'saliendo'
+        print 'quit'
         break
 
 sys.exit(3)
